@@ -212,6 +212,30 @@ def run(context, input, filter, **kwargs):
     context.exit(exit_code)
 
 
+@main.command()
+@click.pass_context
+@IMPLEMENTATION
+@DIALECT
+@SET_SCHEMA
+@click.argument("schema", type=click.File(mode="rb"))
+@click.argument("instances", nargs=-1, type=click.File(mode="rb"))
+def validate(context, schema, instances, **kwargs):
+    """
+    Validate a schema & one or more instances across implementations.
+    """
+    case = TestCase(
+        description="bowtie validate",
+        schema=json.load(schema),
+        tests=[
+            Test(description=str(i), instance=json.load(instance))
+            for i, instance in enumerate(instances, 1)
+        ],
+    )
+    kwargs.update(fail_fast=False, make_validator=do_not_validate)
+    exit_code = asyncio.run(_run(**kwargs, cases=[case]))
+    context.exit(exit_code)
+
+
 @main.command()
 @click.pass_context
 @IMPLEMENTATION
@@ -320,12 +344,12 @@ class _TestSuiteCases(click.ParamType):
 
     def _cases_and_dialect(self, path):
         if path.name.endswith(".json"):
-            files, version_path = [path], path.parent
+            paths, version_path = [path], path.parent
         else:
-            files, version_path = _glob(path, "*.json"), path
+            paths, version_path = _glob(path, "*.json"), path
 
         remotes = version_path.parent.parent / "remotes"
-        cases = suite_cases_from(files=files, remotes=remotes)
+        cases = suite_cases_from(paths=paths, remotes=remotes)
         dialect = DIALECT_SHORTNAMES.get(version_path.name)
 
         return cases, dialect
@@ -470,9 +494,9 @@ def sequenced(cases, reporter):
         yield seq, case, reporter.case_started(seq=seq, case=case)
 
 
-def suite_cases_from(files, remotes):
-    for file in files:
-        if _stem(file) in {"refRemote", "dynamicRef", "vocabulary"}:
+def suite_cases_from(paths, remotes):
+    for path in paths:
+        if _stem(path) in {"refRemote", "dynamicRef", "vocabulary"}:
             registry = {
                 urljoin(
                     "http://localhost:1234",
@@ -483,7 +507,7 @@ def suite_cases_from(files, remotes):
         else:
             registry = {}
 
-        for case in json.loads(file.read_text()):
+        for case in json.loads(path.read_text()):
             for test in case["tests"]:
                 test["instance"] = test.pop("data")
             yield TestCase.from_dict(**case, registry=registry)
@@ -556,7 +580,7 @@ def _relative_to(path, other):
     return Path(path.at).relative_to(other.at)
 
 
-def _stem(path):
+def _stem(path):  # Missing on < 3.11
     if hasattr(path, "stem"):
         return path.stem
     return Path(path.at).stem
